orm — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- action_steps »

# orm

Various `ActionStep` subclasses that inform the GUI of changes in the model.

class `camelot.view.action_steps.orm.` `CreateObject`(obj)

  Inform the GUI that obj was created.

  Parameters: | obj – the object that was created

class `camelot.view.action_steps.orm.` `DeleteObject`(obj)

  Inform the GUI that obj is going to be deleted.

  Parameters: | obj – the object that is going to be deleted

class `camelot.view.action_steps.orm.` `FlushSession`(session)

  Flushes the session and informs the GUI about the changes.

  Parameters: | session – an instance of `sqlalchemy.orm.Session`

class `camelot.view.action_steps.orm.` `UpdateObject`(obj)

  Inform the GUI that obj has changed.

  Parameters: | obj – the object that has changed

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- action_steps »

Comments
blog comments powered by Disqus